<?php

namespace Statamic\Addons\Metapod;

use Statamic\Extend\Addon;

class Helpers extends Addon
{
    /**
     * Get the HTML from a given URL.
     *
     * @author Curtis Blackwell
     * @param  string $url
     * @return string
     */
    public function getHTML($url)
    {
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_CUSTOMREQUEST  => "GET",
            CURLOPT_FOLLOWLOCATION => $this->getConfig('follow_redirects'),
            CURLOPT_HTTP_VERSION   => CURL_HTTP_VERSION_1_1,
            CURLOPT_MAXREDIRS      => $this->getConfig('max_redirects'),
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_TIMEOUT        => $this->getConfig('timeout'),
            CURLOPT_URL            => $url,
        ]);

        $response = curl_exec($curl);
        $err      = curl_error($curl);

        curl_close($curl);

        if ($err) {
            // For now, if there's an error, just log it and return an empty
            // string so the front end doesn't break.
            \Log::ERROR($err);
            return '';
        } else {
            return $response;
        }
    }

    /**
     * Grab all the meta tags from a string.
     *
     * @author Curtis Blackwell
     * @param  string $html
     * @return array
     */
    public function getMetaTags($html)
    {
        preg_match_all('/<meta[^>]*>/', $html, $matches);
        return $matches;
    }

    /**
     * Get all meta tags useable in a template from a string.
     *
     * @author Curtis Blackwell
     * @param  string $html
     * @return array
     */
    public function getMetaTagsForTemplate($html)
    {
        $matches = $this->getMetaTags($html);

        // Keep only those with a `name` or `property` attribute.
        $matches = array_filter(array_get($matches, 0, []), function ($key) {
            return preg_match('/(name|property)="[^"]*"/', $key);
        });

        // Prepare template vars.
        $vars = [];
        foreach ($matches as $match) {
            // Get the `name` or `property` value.
            preg_match_all('/(name|property)="([^"]*)"/', $match, $out);
            $key = str_replace(':', '_', $out[2][0]);

            // Get the `content` or `value` value.
            preg_match_all('/(content|value)="([^"]*)"/', $match, $out);
            $value = $out[2][0];

            $vars[$key] = $value;
        }

        return $vars;
    }
}
